@@ -6,10 +6,15 @@
 // ------------------------------------------------------------------------
 
 use pyo3::{
-    create_exception,
-    exceptions::{PyException, PyNotImplementedError},
-    PyErr,
+    PyErr, create_exception,
+    exceptions::{
+        PyBlockingIOError, PyException, PyNotImplementedError, PyOSError, PyTimeoutError,
+        PyValueError,
+    },
 };
+use std::convert::Infallible;
+
+pub type SnmpResult<T> = Result<T, SnmpError>;
 
 #[derive(Debug)]
 pub enum SnmpError {
@@ -17,7 +22,7 @@ pub enum SnmpError {
     Incomplete,
     /// Other tag is expected
     UnexpectedTag, // @todo: Expand
-    ///
+    /// Unexpecetd tag format
     InvalidTagFormat,
     /// Unknown PDU type
     UnknownPdu,
@@ -25,6 +30,8 @@ pub enum SnmpError {
     InvalidPdu,
     /// Malformed variable data
     InvalidData,
+    /// Invalid key size
+    InvalidKey,
     /// Unimplemented tag
     UnsupportedTag(String),
     /// Data beyound PDU
@@ -37,8 +44,21 @@ pub enum SnmpError {
     NotImplemented,
     /// No such instance
     NoSuchInstance,
+    /// Socket errors
+    SocketError(String),
+    /// Blocking operation
+    WouldBlock,
+    /// Connection refused
+    ConnectionRefused,
+    /// Unknown Security Model
+    UnknownSecurityModel,
+    /// Authentication error
+    AuthenticationFailed,
 }
 
+unsafe impl Send for SnmpError {}
+unsafe impl Sync for SnmpError {}
+
 impl From<nom::Err<SnmpError>> for SnmpError {
     fn from(value: nom::Err<SnmpError>) -> SnmpError {
         match value {
@@ -79,6 +99,7 @@ create_exception!(
     PySnmpError,
     "Requested OID is not found"
 );
+create_exception!(_fast, PySnmpAuthError, PySnmpError, "Authentication failed");
 
 impl From<SnmpError> for PyErr {
     fn from(value: SnmpError) -> PyErr {
@@ -89,6 +110,7 @@ impl From<SnmpError> for PyErr {
             SnmpError::UnknownPdu => PySnmpDecodeError::new_err("unknown pdu"),
             SnmpError::InvalidPdu => PySnmpDecodeError::new_err("invalid pdu"),
             SnmpError::InvalidData => PySnmpDecodeError::new_err("invalid data"),
+            SnmpError::InvalidKey => PyValueError::new_err("invalid key"),
             SnmpError::UnsupportedTag(e) => {
                 PySnmpDecodeError::new_err(format!("Unsupported tag: {}", e))
             }
@@ -99,6 +121,17 @@ impl From<SnmpError> for PyErr {
             SnmpError::OutOfBuffer => PySnmpEncodeError::new_err("out of buffer"),
             SnmpError::NotImplemented => PyNotImplementedError::new_err("not implemented"),
             SnmpError::NoSuchInstance => PyNoSuchInstance::new_err("no such instance"),
+            SnmpError::WouldBlock => PyBlockingIOError::new_err("blocked"),
+            SnmpError::SocketError(x) => PyOSError::new_err(x),
+            SnmpError::ConnectionRefused => PyTimeoutError::new_err("connection refused"),
+            SnmpError::UnknownSecurityModel => PySnmpDecodeError::new_err("unknown security model"),
+            SnmpError::AuthenticationFailed => PySnmpAuthError::new_err("authentication failed"),
         }
     }
 }
+
+impl From<Infallible> for SnmpError {
+    fn from(_value: Infallible) -> Self {
+        todo!("Should never happen")
+    }
+}
